@@ -52,7 +52,6 @@ __all__ = [
     'Bitwise',
     'Byte',
     'Bytes',
-    'Bytes',
     'BytesInteger',
     'ByteSwapped',
     'Bytewise',
@@ -78,13 +77,13 @@ __all__ = [
     'ExprAdapter',
     'ExprSymmetricAdapter',
     'ExprValidator',
-    'FieldError',
     'Filter',
     'Flag',
     'FlagsContainer',
     'FlagsEnum',
     'FocusedSeq',
     'FormatField',
+    'FormatFieldError',
     'globalfullprinting',
     'globalstringencoding',
     'GreedyBytes',
@@ -158,6 +157,7 @@ __all__ = [
     'SizeofError',
     'Slicing',
     'StopIf',
+    'StreamError',
     'String',
     'StringError',
     'Struct',
@@ -172,7 +172,6 @@ __all__ = [
     'TerminatedError',
     'this',
     'Tunnel',
-    'Tunnel',
     'Union',
     'UnionError',
     'ValidationError',
