@@ -7,7 +7,7 @@ from construct import *
 #===============================================================================
 # pixels: uncompressed
 #===============================================================================
-def UncompressedRows(subcon, align_to_byte = False):
+def UncompressedRows(subcon, align_to_byte=False):
     """argh! lines must be aligned to a 4-byte boundary, and bit-pixel lines must be aligned to full bytes..."""
     if align_to_byte:
         line_pixels = Bitwise(Aligned(8, Array(this.width, subcon)))
@@ -15,10 +15,10 @@ def UncompressedRows(subcon, align_to_byte = False):
         line_pixels = Array(this.width, subcon)
     return Array(this.height, Aligned(4, line_pixels))
 
-uncompressed_pixels = "uncompressed" / Switch(this.bpp,
+uncompressed_pixels = Switch(this.bpp,
     {
-        1 : UncompressedRows(Bit, align_to_byte = True), # index
-        4 : UncompressedRows(Nibble, align_to_byte = True), # index
+        1 : UncompressedRows(Bit, align_to_byte=True), # index
+        4 : UncompressedRows(Nibble, align_to_byte=True), # index
         8 : UncompressedRows(Byte),  # index
         24 : UncompressedRows(Byte[3]),  # rgb
     }
@@ -31,15 +31,16 @@ class RunLengthAdapter(Adapter):
     def _encode(self, obj):
         return len(obj), obj[0]
     def _decode(self, obj):
-        length, value = obj
+        length,value = obj
         return [value] * length
 
+# WARNING: not used anywhere
 rle8pixel = "rle8pixel" / RunLengthAdapter(Byte >> Byte)
 
 #===============================================================================
 # file structure
 #===============================================================================
-bitmap_file = "bitmap_file" / Struct(
+bitmap_file = Struct(
     "signature" / Const(b"BM"),
     "file_size" / Int32ul,
     Padding(4),
@@ -71,18 +72,10 @@ bitmap_file = "bitmap_file" / Struct(
     "important_colors" / Int32ul,
 
     # palette (24 bit has no palette)
-    "palette" / Array(lambda ctx: 2**ctx.bpp if ctx.bpp <= 8 else 0,
-        Struct(
-            "rgb" / Byte[3],
-            Padding(1),
-        )
-    ),
+    # NOTE: was called "rgb" inside of it
+    "palette" / Array(lambda ctx: 2**ctx.bpp if ctx.bpp <= 8 else 0, Padded(4, Byte[3])),
 
     "pixels" / Pointer(this.data_offset,
-        Switch(this.compression,
-            {
-                "Uncompressed" : uncompressed_pixels,
-            },
-        ),
+        Switch(this.compression, {"Uncompressed" : uncompressed_pixels}),
     ),
 )
